@@ -10,7 +10,7 @@ class SklearnTransformerMixin(BaseEstimator, TransformerMixin):
     def fit(self, X, y=None):
         """
         Will fit the language model such that it is ready for use in scikit learn.
-        Check out the [guide](https://rasahq.github.io/whatlies/tutorial/languages/#scikit-learn) for more details.
+        Check out the [guide](https://koaning.github.io/whatlies/tutorial/languages/#scikit-learn) for more details.
         """
         if not np.array(X).dtype.type is np.str_:
             raise ValueError("You must give this preprocessor text as input.")
@@ -29,7 +29,7 @@ class SklearnTransformerMixin(BaseEstimator, TransformerMixin):
     def transform(self, X):
         """
         Will apply the transformer as if it is a scikit-learn text feature extractor.
-        Check out the [guide](https://rasahq.github.io/whatlies/tutorial/languages/#scikit-learn) for more details.
+        Check out the [guide](https://koaning.github.io/whatlies/tutorial/languages/#scikit-learn) for more details.
         """
         check_is_fitted(self, "fitted_")
         if not np.array(X).dtype.type is np.str_:
