@@ -39,7 +39,9 @@ class DIETLanguage(SklearnTransformerMixin):
     **Usage**:
 
     ```python
-    from whatlies.language import DIETLanguage("path/to/model.tar.gz")
+    from whatlies.language import DIETLanguage
+
+    lang = DIETLanguage("path/to/model.tar.gz")
     lang[['hi', 'hello', 'greetings']]
     ```
     """
@@ -63,7 +65,9 @@ class DIETLanguage(SklearnTransformerMixin):
 
         **Usage**
         ```python
-        from whatlies.language import DIETLanguage("path/to/model.tar.gz")
+        from whatlies.language import DIETLanguage
+
+        lang = DIETLanguage("path/to/model.tar.gz")
         lang[['hi', 'hello', 'greetings']]
         ```
         """
